@@ -101,8 +101,7 @@ class TaskAssignator:
                                 f"assigned ipt {ipt} -> ico {ico} ->"+\
                                 f"ids {ids}"
                                 level = 20
-                                scheduler.queue_log.put(("Assignator",
-                                                         msg, level, {}))
+                                await scheduler.send_log("Assignator", level, msg, [])                                
 
                                 dt_group.remove(element)
 
@@ -118,8 +117,8 @@ class TaskAssignator:
                             f"assigned ipt {ipt} -> ico {ico} ->"+\
                             f"ids {ids}"
                             level = 20
-                            scheduler.queue_log.put(("Assignator",
-                                                     msg, level, {}))
+                            
+                            await scheduler.send_log("Assignator", level, msg, [])
 
                             print(self.scheduler.assigned_tasks)
                             self.scheduler.add_sta_assigned(
@@ -131,10 +130,9 @@ class TaskAssignator:
                     else:
                         msg = f"All slots are "+\
                               f"used, can't add the station {code} ids {ids}"
-                        print(now(), "Assignator", msg)
                         level = 30 #warning
-                        scheduler.queue_log.put(("Assignator", msg,
-                                                 level, {}))
+                        await scheduler.send_log("Assignator", level, msg, [])
+                        
                 queue_tasks.task_done()
             else:
                 pass
