@@ -54,6 +54,9 @@ class TaskScheduler:
                 ipt = my_random_string(uin)
         return ipt
 
+    async def send_log(self, coroname, level, message, exc):
+        pass
+
     def set_ico(self, ico):
         """
         Defines a new id for task related to collect data
